@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use version;
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 use Prancer::Plugin;
 use parent qw(Prancer::Plugin Exporter);
@@ -116,18 +116,6 @@ sub _database {
 
     # no connections actually exist
     croak "could not get connection to database: no connections defined\n";
-
-#     my $self = shift;
-#     my $connection = shift;
-#     my $connection = shift || "default";
-#
-#
-#
-#     if (!exists($self->{'_handles'}->{$connection})) {
-#         croak "could not get connection to database: no connection named '${connection}'";
-#     }
-#
-#     return $self->{'_handles'}->{$connection}->handle();
 }
 
 1;
@@ -170,21 +158,33 @@ file:
                     - SET search_path=public
 
 The "connection-name" can be anything you want it to be. This will be used when
-requesting a connection from the plugin to determine which connection to return.
-If only one connection is configured it may be prudent to call it "default" as
-that is the name that Prancer will look for if no connection name is given.
-For example:
+requesting a connection from the plugin to determine which connection to
+return. If only one connection is configured and no specific connection name is
+requested then the only configured connection will be returned. If more than
+one connection is configured and no specific connection name is requested then
+any connection that is named "default" will be used. Otherwise an error will be
+thrown. For example:
 
     use Prancer::Plugin::Database qw(database);
 
     Prancer::Plugin::Database->load();
 
-    my $dbh = database;  # returns whatever connection is called "default"
-    my $dbh = database("foo");  # returns the connection called "foo"
+    # if only one connection is configured then this will return that
+    # connection
+    my $dbh = database;
+
+    # if multiple connections are configured and one of them is called
+    # "default" then this will return the connection named "default" or throw
+    # an error if no connection is named "default"
+    my $dbh = database;
+
+    # this will return a configured connection named "foo" or throw an error if
+    # no connections are named "foo"
+    my $dbh = database("foo");
 
 =head1 OPTIONS
 
-=over 4
+=over
 
 =item database
 
@@ -254,7 +254,7 @@ Precious.
 
 =head1 COPYRIGHT
 
-Copyright 2014 Paul Lockaby. All rights reserved.
+Copyright 2014, 2015 Paul Lockaby. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
